@@ -125,8 +125,8 @@ class NxPyDocs():
         env = Environment(loader=FileSystemLoader(str(template_dir)))
         csv_template = env.get_template('csv.j2')
         csv_output = csv_template.render(command = self.command,
-            data_to_template=json.dumps(parsed_json),
-            hostname=self.hostname)
+            data_to_template=json.dumps(parsed_json)
+            )
         with open('%s.csv' % self.command, 'w') as f:
             f.write(csv_output)
         print(csv_output)
@@ -138,8 +138,8 @@ class NxPyDocs():
         env = Environment(loader=FileSystemLoader(str(template_dir)))
         mindmap_template = env.get_template('mindmap.j2')
         mindmap_output = mindmap_template.render(command = self.command,
-            data_to_template=json.dumps(parsed_json),
-            hostname=self.hostname)
+            data_to_template=json.dumps(parsed_json)
+            )
         with open('%s mindmap.md' % self.command, 'w') as f:
             f.write(mindmap_output)
         print(mindmap_output)
